@@ -20,11 +20,13 @@ import re
 # Python 3 imports that throw in Python 2
 try:
     import queue
-    import html.parser as HTMLParser
+    from html import unescape
 except ImportError:
     # This is Python 2
     import Queue as queue
     import HTMLParser
+    html_parser = HTMLParser.HTMLParser()
+    unescape = html_parser.unescape
 
 import threading
 from gallery_utils import *
@@ -32,8 +34,6 @@ from gallery_plugins import *
 import multiprocessing
 import calendar
 
-html_parser = HTMLParser.HTMLParser()
-
 QUEUE = queue.Queue()
 STANDBY = False
 THREADS = []
@@ -55,10 +55,13 @@ PARAMS = []
 
 
 def safe_str(name):
-    name = name.replace(":",";") # to preserve emoticons
-    name = "".join(i for i in name if ord(i)<128)
-    name = html_parser.unescape(name)
-    return re.sub(r"[\/\\\*\?\"\<\>\|]", "", name).strip().rstrip(".")
+    if is_str(name):
+        name = name.replace(":",";") # to preserve emoticons
+        name = "".join(i for i in name if ord(i)<128)
+        name = unescape(name)
+        return re.sub(r"[\/\\\*\?\"\<\>\|]", "", name).strip().rstrip(".")
+    else:
+        return str(name)
 
 def safe_unpack(obj, default):
     if is_str(obj):
@@ -182,7 +185,8 @@ class JobInfo(object):
         try:
             if not self.data:
                 self.data = file_info.read()
-        except:
+        except Exception as error:
+            print(error)
             success = False
 
         file_info.close()
@@ -246,7 +250,8 @@ class ImgThread(threading.Thread):
         file_name = info.destination_filename()
         try:
             file_info = urlopen_safe(info.path)
-        except:
+        except Exception as error:
+            print(error)
             return False
 
         try:
@@ -428,16 +433,24 @@ class GalleryGet(object):
         ### TRY OPENING URL
         try:
             # Don't use urlopen_text here.  We want to capture when the data is in bytes, and treat as image
-            data = urlopen_safe(self.url)
-            time.sleep(self.plugin.page_load_time)
-            page = data.read().decode('utf-8')
-        except:
-            if (self.folder != DEST_ROOT) and ("." in urlparse(self.url).path):
+            if self.plugin.needs_javascript:
+                source = urlopen_js(self.url)
+                page = unicode_safe(source)
+            else:
+                data = urlopen_safe(self.url)
+                time.sleep(self.plugin.page_load_time)
+                page = unicode_safe(data.read())
+        except Exception as error:
+            if ("certificate verify failed" in str(error)):
+                print("ERROR: Python doesn't have SSL certificates installed, can't access " + self.url)
+                print("Please run 'Install Certificates.command' from your Python installation directory.")
+                return False
+            elif (self.folder != DEST_ROOT) and ("." in urlparse(self.url).path):
                 # this could be a direct image
                 return download_image(self.url, self.folder)
-
-            print("Skipping inaccessible link: " + self.url)
-            return False
+            else:
+                print("Skipping inaccessible link (%s): %s" % (self.url, error))
+                return False
 
         ### BEGIN PROCESSING
         (root, subtitle) = self.get_root_and_subtitle(page)
